#[repr(i32)]pub enum BlockHashAlgorithm {
Sha2384 = 0,
}Expand description
A specific hash algorithm.
We did not reuse Record Stream HashAlgorithm here because in all cases,
currently, this will be SHA2_384 and if that is the default value then
we can save space by not serializing it, whereas HASH_ALGORITHM_UNKNOWN
is the default for Record Stream HashAlgorithm.
Note that enum values here MUST NOT match the name of any other enum value
in the same package, as protobuf follows C++ scope rules and all enum
names are treated as global constants within the package.
Variants
Sha2384 = 0
A SHA2 algorithm SHA-384 hash.
This is the default value, if a field of this enumerated type is not set, then this is the value that will be decoded when the serialized message is read.
Implementations
Sourceimpl BlockHashAlgorithm
impl BlockHashAlgorithm
Sourcepub fn from_i32(value: i32) -> Option<BlockHashAlgorithm>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<BlockHashAlgorithm>
Use the TryFrom<i32> implementation instead
Converts an i32 to a BlockHashAlgorithm, or None if value is not a valid variant.
Sourceimpl BlockHashAlgorithm
impl BlockHashAlgorithm
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.