pub struct FileGetInfoQuery {
pub header: Option<QueryHeader>,
pub file_id: Option<FileId>,
}Expand description
Query to request file metadata from the Hedera File Service (HFS).
This query requests all of the information about a file, but none of the
content of a file. A client should submit a fileGetContents query to
view the content of a file. File content may also be available from a
block node or mirror node, generally at lower cost.
File metadata SHALL be available for active files and deleted files.
The size of a deleted file SHALL be 0 and the content SHALL be empty.
Fields
header: Option<QueryHeader>Standard information sent with every query operation.
This includes the signed payment and what kind of response is requested
(cost, state proof, both, or neither).
file_id: Option<FileId>A file identifier.
This MUST be the identifier of a file that exists in HFS.
This value SHALL identify the file to be queried.