pub struct GetByKeyQuery {
pub header: Option<QueryHeader>,
pub key: Option<Key>,
}Expand description
Query all accounts, claims, files, and smart contract instances whose associated keys include the given Key.
This query is no longer supported.
Fields
header: Option<QueryHeader>Standard information sent with every query operation.
This includes the signed payment and what kind of response is requested
(cost, state proof, both, or neither).
key: Option<Key>The key to search for. It MUST NOT contain a contractID nor a ThresholdKey.