pub struct TransactionGetFastRecordQuery {
pub header: Option<QueryHeader>,
pub transaction_id: Option<TransactionId>,
}Expand description
Get the tx record of a transaction, given its transaction ID.
Once a transaction reaches consensus, then information about whether it
succeeded or failed will be available until the end of the receipt period.
Before and after the receipt period, and for a transaction that was never
submitted, the receipt is unknown.
This query is free (the payment field is left empty).
Fields
header: Option<QueryHeader>Standard information sent with every query operation.
This includes the signed payment and what kind of response is requested
(cost, state proof, both, or neither).
transaction_id: Option<TransactionId>The ID of the transaction for which the record is requested.