pub struct FileUpdateTransactionBody {
pub file_id: Option<FileId>,
pub expiration_time: Option<Timestamp>,
pub keys: Option<KeyList>,
pub contents: Vec<u8>,
pub memo: Option<String>,
}Expand description
Update the metadata, and/or replace the content, of a file in the Hedera File Service (HFS).
Any field which is not set (i.e. is null) in this message, other than
fileID, SHALL be ignored.
If the keys list for the identified file is an empty KeyList, then
this message MUST NOT set any field except expirationTime.
Signature Requirements
Every Key in the keys list for the identified file MUST sign this
transaction, if any field other than expirationTime is to be updated.
If the keys list for the identified file is an empty KeyList (because
this file was previously created or updated to have an empty KeyList),
then the file is considered immutable and this message MUST NOT set any
field except expirationTime.
See the File Service specification for a detailed
explanation of the signature requirements for all file transactions.
Block Stream Effects
None
Fields
file_id: Option<FileId>A file identifier for the file to update.
This field is REQUIRED.
expiration_time: Option<Timestamp>An expiration timestamp.
If set, this value MUST be strictly later than the existing
`expirationTime` value, or else it will be ignored.
If set, this value SHALL replace the existing `expirationTime`.
If this field is the only field set, then this transaction SHALL NOT
require any signature other than the `payer` for the transaction.
When the network consensus time exceeds the then-current
`expirationTime`, the network SHALL expire the file.
keys: Option<KeyList>The new list of keys that “own” this file.
If set, every key in this `KeyList` MUST sign this transaction.
If set, every key in the _previous_ `KeyList` MUST _also_
sign this transaction.
If this value is an empty `KeyList`, then the file SHALL be immutable
after completion of this transaction.
contents: Vec<u8>An array of bytes.
This value, if set, SHALL _replace_ the existing file content. If this value is set to an empty byte array, the content of the file SHALL be unchanged.
memo: Option<String>A short description of this file.
This value, if set, MUST NOT exceed `transaction.maxMemoUtf8Bytes` (default 100) bytes when encoded as UTF-8.